@@ -12,6 +12,8 @@
 from cqrcode.view.GUI_welcome import hello
 
 while True:
-    x = input('请输入 s 启动...\n')
+    x = input('type 's' to start...（target figure saves in ~.\Lib\site-packages\cqrcode\static\）\n')
     if x == 's' or x == 'S':
         hello()
+    else:
+        break
