@@ -13,10 +13,10 @@ import tkinter as tk
 import os
 from tkinter import filedialog
 
-from cylinder_qrcode_project.cqrcode.app.scan_figure import scan_cylinder_qr_code
-from cylinder_qrcode_project.cqrcode.app.run import main
-from cylinder_qrcode_project.cqrcode.app.QRcode import create_QRcode
-from view.GUI_view import window
+from cqrcode.app.scan_figure import scan_cylinder_qr_code
+from cqrcode.app.run import main
+from cqrcode.app.QRcode import create_QRcode
+from cqrcode.view.GUI_view import window
 
 scaleValue = None
 rawPath = os.path.abspath(__file__)
